# DASCore

A python library for distributed fiber optic sensing.

[![coverage](https://codecov.io/gh/dasdae/dascore/branch/master/graph/badge.svg)](https://codecov.io/gh/dasdae/dascore)
[![supported versions](https://img.shields.io/pypi/pyversions/dascore.svg?label=python_versions)](https://pypi.python.org/pypi/dascore)
[![PyPI Downloads](https://img.shields.io/pypi/dm/dascore.svg?label=pypi)](https://pypi.org/project/dascore/)
[![Conda Downloads](https://img.shields.io/conda/dn/conda-forge/dascore.svg?label=conda)](https://github.com/conda-forge/dascore-feedstock)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.7373559.svg)](https://doi.org/10.5281/zenodo.7373559)
[![Licence](https://www.gnu.org/graphics/lgplv3-88x31.png)](https://www.gnu.org/licenses/lgpl.html)

[Documentation](https://dascore.org)

[Code](https://github.com/DASDAE/dascore)

**WARNING**: dascore is still very new. There will be bugs and API changes.
